Clazz.declarePackage("J.api");
Clazz.load(["J.api.FontManager"], "J.api.GenericPlatform", null, function(){
var c$ = Clazz.declareInterface(J.api, "GenericPlatform", J.api.FontManager);
});
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
